@@ -60,7 +60,7 @@ std::string read_from_disk(const std::string& filepath)
 
 int main(int argc, char* argv[])
 {
-  Glib::ustring filepath;
+  std::string filepath;
   if(argc > 1 )
     filepath = argv[1]; //Allow the user to specify a different XML file to parse.
   else
